@@ -103,23 +103,7 @@ func ensureContainer(modified *bool, existing *corev1.Container, required corev1
 	ensureEnvFromSource(modified, &existing.EnvFrom, required.EnvFrom)
 	setStringIfSet(modified, &existing.WorkingDir, required.WorkingDir)
 	ensureResourceRequirements(modified, &existing.Resources, required.Resources)
-
-	// any port we specify, we require
-	for _, required := range required.Ports {
-		var existingCurr *corev1.ContainerPort
-		for j, curr := range existing.Ports {
-			if curr.Name == required.Name {
-				existingCurr = &existing.Ports[j]
-				break
-			}
-		}
-		if existingCurr == nil {
-			*modified = true
-			existing.Ports = append(existing.Ports, corev1.ContainerPort{})
-			existingCurr = &existing.Ports[len(existing.Ports)-1]
-		}
-		ensureContainerPort(modified, existingCurr, required)
-	}
+	ensureContainerPorts(modified, &existing.Ports, required.Ports)
 
 	// any volume mount we specify, we require
 	for _, required := range required.VolumeMounts {
@@ -138,12 +122,8 @@ func ensureContainer(modified *bool, existing *corev1.Container, required corev1
 		ensureVolumeMount(modified, existingCurr, required)
 	}
 
-	if required.LivenessProbe != nil {
-		ensureProbePtr(modified, &existing.LivenessProbe, required.LivenessProbe)
-	}
-	if required.ReadinessProbe != nil {
-		ensureProbePtr(modified, &existing.ReadinessProbe, required.ReadinessProbe)
-	}
+	ensureProbePtr(modified, &existing.LivenessProbe, required.LivenessProbe)
+	ensureProbePtr(modified, &existing.ReadinessProbe, required.ReadinessProbe)
 
 	// our security context should always win
 	ensureSecurityContextPtr(modified, &existing.SecurityContext, required.SecurityContext)
@@ -170,11 +150,10 @@ func ensureEnvFromSource(modified *bool, existing *[]corev1.EnvFromSource, requi
 }
 
 func ensureProbePtr(modified *bool, existing **corev1.Probe, required *corev1.Probe) {
-	// if we have no required, then we don't care what someone else has set
-	if required == nil {
+	if *existing == nil && required == nil {
 		return
 	}
-	if *existing == nil {
+	if *existing == nil || required == nil {
 		*modified = true
 		*existing = required
 		return
@@ -195,6 +174,37 @@ func ensureProbeHandler(modified *bool, existing *corev1.Handler, required corev
 	}
 }
 
+func ensureContainerPorts(modified *bool, existing *[]corev1.ContainerPort, required []corev1.ContainerPort) {
+	for i := len(*existing) - 1; i >= 0; i-- {
+		existingContainerPort := &(*existing)[i]
+		var existingCurr *corev1.ContainerPort
+		for _, requiredContainerPort := range required {
+			if existingContainerPort.Name == requiredContainerPort.Name {
+				existingCurr = &(*existing)[i]
+				ensureContainerPort(modified, existingCurr, requiredContainerPort)
+				break
+			}
+		}
+		if existingCurr == nil {
+			*modified = true
+			*existing = append((*existing)[:i], (*existing)[i+1:]...)
+		}
+	}
+	for _, requiredContainerPort := range required {
+		match := false
+		for _, existingContainerPort := range *existing {
+			if existingContainerPort.Name == requiredContainerPort.Name {
+				match = true
+				break
+			}
+		}
+		if !match {
+			*modified = true
+			*existing = append(*existing, requiredContainerPort)
+		}
+	}
+}
+
 func ensureContainerPort(modified *bool, existing *corev1.ContainerPort, required corev1.ContainerPort) {
 	if !equality.Semantic.DeepEqual(required, *existing) {
 		*modified = true
